DashComponentInfo
=================

.. currentmodule:: dash_component_template.template

.. autoclass:: DashComponentInfo
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~DashComponentInfo.from_component_cls

   .. rubric:: Methods Documentation

   .. automethod:: from_component_cls
